import os
from typing import Final

from setuptools import find_packages, setup

from mdrsclient import __version__

BASE_DIR: Final[str] = os.path.realpath(os.path.dirname(__file__))

with open(os.path.join(BASE_DIR, "requirements.txt")) as f:
    __requirements__ = f.read().splitlines()

with open(os.path.join(BASE_DIR, "README.md")) as f:
    __readme__ = f.read()

setup(
    name="mdrsclient",
    version=__version__,
    description="A MDRS command-line tool",
    long_description=__readme__,
    author="Neuroinformatics Unit, RIKEN CBS",
    license="MIT",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "OSI Approved :: MIT License",
        "Topic :: Utilities",
    ],
    packages=find_packages(),
    include_package_data=True,
    package_data={
        "mdrsclient": ["VERSION"],
    },
    install_requires=__requirements__,
    entry_points={"console_scripts": ["mdrs=mdrsclient.__main__:main"]},
)
